/**********************************************************************
* File: F2808_example.h
* Device: TMS320F2808
* Author: David M. Alter, Texas Instruments Inc.
* Description: Include file for example project.  Include this file in
*   all C-source files.
* Notes:
*   1) The following constants may be defined in the CCS project build
*      options:
*        EXAMPLE_NONBIOS
*        EXAMPLE_BIOS5
*        EXAMPLE_FLASH
*        EXAMPLE_RAM
* History:
*   12/13/07 - original (D. Alter)
**********************************************************************/

#ifndef F2808_EXAMPLE_H
#define F2808_EXAMPLE_H


//---------------------------------------------------------------------
// Constant Definitions
//
#define ADC_BUF_LEN			50				// ADC buffer length
#define ADC_SAMPLE_PERIOD	1999			// 1999 = 50 KHz sampling w/ 100 MHz SYSCLKOUT
#define PWM_HALF_PERIOD		25000			// period/2 for 2 kHz symmetric PWM
#define PWM_DUTY_CYCLE		18750			// 25% duty cycle


//---------------------------------------------------------------------
// Include Standard C Language Header Files
//
#include <string.h>


//---------------------------------------------------------------------
// Include Any Other Header Files
//
#include "DSP280x_Device.h"					// Peripheral address definitions

#ifdef EXAMPLE_NONBIOS
	#include "DSP280x_DefaultIsr.h"			// ISR definitions
#endif

#ifdef EXAMPLE_BIOS5
	#ifdef EXAMPLE_FLASH
	    #include "F2808_example_BIOS5_flashcfg.h"
	#endif

	#ifdef EXAMPLE_RAM
	    #include "F2808_example_BIOS5_ramcfg.h"
	#endif
#endif


//---------------------------------------------------------------------
// Function Prototypes
//
extern void DelayUs(Uint16);
extern void InitAdc(void);
extern void InitECap(void);
extern void InitEPwm(void);

#ifdef EXAMPLE_FLASH
	extern void InitFlash(void);
#endif

extern void InitGpio(void);
extern void InitPieCtrl(void);
extern void InitSysCtrl(void);
extern void InitWatchdog(void);
extern void SetDBGIER(Uint16);

#ifdef EXAMPLE_BIOS5
	extern void UserInit(void);
#endif


//---------------------------------------------------------------------
// Global Symbols Defined In The Linker Command File
//
#ifdef EXAMPLE_BIOS5
	extern Uint16 hwi_vec_loadstart;
	extern Uint16 hwi_vec_loadsize;
	extern Uint16 hwi_vec_runstart;
	extern Uint16 trcdata_loadstart;
	extern Uint16 trcdata_loadsize;
	extern Uint16 trcdata_runstart;
#endif

#ifdef EXAMPLE_FLASH
	extern Uint16 secureRamFuncs_loadstart;
	extern Uint16 secureRamFuncs_loadsize;
	extern Uint16 secureRamFuncs_runstart;
#endif


//---------------------------------------------------------------------
// Global Variable References
//
extern Uint16 AdcBuf[ADC_BUF_LEN];			// ADC data buffer allocation
extern Uint32 PwmDuty;						// measured PWM duty cycle
extern Uint32 PwmPeriod;					// measured PWM period

#ifdef EXAMPLE_NONBIOS
	extern const struct PIE_VECT_TABLE PieVectTableInit;	// Pie vector table (non-BIOS only)
#endif


//---------------------------------------------------------------------
#endif  // end of F2808_EXAMPLE_H definition


//--- end of file -----------------------------------------------------
